pub enum XMark {
Mark0,
Mark1,
Mark2,
}Expand description
The mark type used in the XArray.
The XArray itself and an item in it can have up to three different marks.
Users can use a self-defined type to distinguish which kind of mark they want to set. Such a
type must implement the Into<XMark> trait.
Variants